Utilities
===================================
.. automodule:: ants

.. autofunction:: n3_bias_field_correction
.. autofunction:: n4_bias_field_correction
.. autofunction:: abp_n4
.. autofunction:: merge_channels
.. autofunction:: split_channels
.. autofunction:: crop_image
.. autofunction:: crop_indices
.. autofunction:: decrop_image
.. autofunction:: denoise_image
.. autofunction:: fit_bspline_object_to_scattered_data
.. autofunction:: fit_bspline_displacement_field
.. autofunction:: functional_lung_segmentation
.. autofunction:: get_ants_data
.. autofunction:: get_centroids
.. autofunction:: get_mask
.. autofunction:: image_similarity
.. autofunction:: image_to_cluster_images
.. autofunction:: iMath
.. autofunction:: impute
.. autofunction:: label_clusters
.. autofunction:: label_image_centroids
.. autofunction:: label_overlap_measures
.. autofunction:: mask_image
.. autofunction:: mni2tal
.. autofunction:: morphology
.. autofunction:: get_pointer_string
.. autofunction:: simulate_displacement_field
.. autofunction:: smooth_image
.. autofunction:: threshold_image
.. autofunction:: weingarten_image_curvature
.. autofunction:: from_sitk
.. autofunction:: to_sitk
